Module tauri_codegen::embedded_assets [−][src]
Structs
| AssetOptions | Options used to embed assets. |
| EmbeddedAssets | Represent a directory of assets that are compressed and embedded. |
Enums
| EmbeddedAssetsError | All possible errors while reading and compressing an |